/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyMetricConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric#id DataLaunchdarklyMetric#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Ignored. All metrics are considered active.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric#is_active DataLaunchdarklyMetric#is_active}
    */
    readonly isActive?: boolean | cdktf.IResolvable;
    /**
    * The unique key that references the metric. A change in this field will force the destruction of the existing resource and the creation of a new one.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric#key DataLaunchdarklyMetric#key}
    */
    readonly key: string;
    /**
    * The metrics's project key. A change in this field will force the destruction of the existing resource and the creation of a new one.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric#project_key DataLaunchdarklyMetric#project_key}
    */
    readonly projectKey: string;
}
export interface DataLaunchdarklyMetricUrls {
}
export declare function dataLaunchdarklyMetricUrlsToTerraform(struct?: DataLaunchdarklyMetricUrls): any;
export declare function dataLaunchdarklyMetricUrlsToHclTerraform(struct?: DataLaunchdarklyMetricUrls): any;
export declare class DataLaunchdarklyMetricUrlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyMetricUrls | undefined;
    set internalValue(value: DataLaunchdarklyMetricUrls | undefined);
    get kind(): string;
    get pattern(): string;
    get substring(): string;
    get url(): string;
}
export declare class DataLaunchdarklyMetricUrlsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyMetricUrlsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric launchdarkly_metric}
*/
export declare class DataLaunchdarklyMetric extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_metric";
    /**
    * Generates CDKTF code for importing a DataLaunchdarklyMetric resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataLaunchdarklyMetric to import
    * @param importFromId The id of the existing DataLaunchdarklyMetric that should be imported. Refer to the {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataLaunchdarklyMetric to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.22.0/docs/data-sources/metric launchdarkly_metric} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyMetricConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyMetricConfig);
    get analysisType(): string;
    get description(): string;
    get eventKey(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get includeUnitsWithoutEvents(): cdktf.IResolvable;
    private _isActive?;
    get isActive(): boolean | cdktf.IResolvable;
    set isActive(value: boolean | cdktf.IResolvable);
    resetIsActive(): void;
    get isActiveInput(): boolean | cdktf.IResolvable | undefined;
    get isNumeric(): cdktf.IResolvable;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    get kind(): string;
    get maintainerId(): string;
    get name(): string;
    get percentileValue(): number;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    get randomizationUnits(): string[];
    get selector(): string;
    get successCriteria(): string;
    get tags(): string[];
    get unit(): string;
    get unitAggregationType(): string;
    private _urls;
    get urls(): DataLaunchdarklyMetricUrlsList;
    get version(): number;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
